@@ -2,6 +2,21 @@ import PySimpleGUI as sg
 
 import traceback
 
+column_mappings = {'Order Date': 0,
+ 'Order ID': 1,
+ 'Item Name': 2,
+ 'ASIN': 3,
+ 'SKU': 4,
+ 'STORE': 5,
+ 'COST PER UNIT': 6,
+ 'INDV ITEMS QTY': 7,
+ 'SELLABLE QTY': 8,
+ 'Condition': 9,
+ 'ORDER COST': 10,
+ 'PRICE': 11,
+ 'ISBN': 12,
+ 'USPC': 13,
+ 'EAN': 14}
 
 def debug_basic(value):
     if value:
@@ -50,7 +65,7 @@ def get_input_user_wrapper(input_function):
 @get_input_user_wrapper
 def select_name_and_click_ok_or_terminate(name, keep_on_top, affirmative_response):
     #affirmative_response is required for the decorator to work
-    event = sg.popup(f"Please select {name} and click ok when finished",
+    event = sg.popup(f"Please select {name} and click 'OK' when finished",
     keep_on_top=keep_on_top)
     return event
 
@@ -58,7 +73,7 @@ def select_name_and_click_ok_or_terminate(name, keep_on_top, affirmative_respons
 def ask_to_go_to_wb_click_ok_or_terminate(name, keep_on_top, affirmative_response):
     #affirmative_response is required for the decorator to work and cannot be gieven a 
     #default argument, but "OK" should always be passed in as a keyword argument for it
-    event = sg.popup(f"Please make {name} your active Excel sheet and click ok when finished",
+    event = sg.popup(f"Please make {name} your active Excel sheet and click 'OK' when finished",
     keep_on_top=keep_on_top)
     return event
 
@@ -68,7 +83,7 @@ def get_file(text, affirmative_response, value_dict):
     #to return the values, and return the event
     layout = [[sg.Text(f'Select the file location of {text}'), sg.Input(),sg.FileBrowse(key="--input_file--")],
                 [sg.OK(), sg.Cancel()]]
-    event, values = sg.Window("",layout, no_titlebar=True, keep_on_top=True, grab_anywhere=True).read(close=True)
+    event, values = sg.Window("",layout, keep_on_top=True, grab_anywhere=True).read(close=True)
     value_dict["val"] = values["--input_file--"]
     return event
 
@@ -182,7 +197,7 @@ def export_data(use_Process=False):
     
 
 
-    select_name_and_click_ok_or_terminate("Product Keys", keep_on_top=True, affirmative_response={"OK"})
+    select_name_and_click_ok_or_terminate("ASINs", keep_on_top=True, affirmative_response={"OK"})
 
 
     current_address = xw.apps.active.books.active.selection.address
@@ -326,10 +341,22 @@ def generate_sku(allowed_data_types = [str]):
     import xlwings as xw
     input_col_name_1 = xw.apps.active.books.active.selection.value
     input_col_name_1_address = xw.apps.active.books.active.selection.address
+    asin_list = input_col_name_1
+
+
+    from get_other_row_data import get_other_row_data
+    date_list=get_other_row_data(column_mappings, curr_attr="ASIN", new_attr="Order Date", 
+    target_sheet=xw.apps.active.books.active.sheets.active,
+    target_address=input_col_name_1_address)
+    
+
+    sku_list = []
+    from inventory_data import get_attribute
+    asin_sku_dict = get_attribute('seller-sku') #Ethan
+    import datetime
     select_name_and_click_ok_or_terminate("SKU column", keep_on_top=True, affirmative_response={"OK"})
     active_cells = xw.apps.active.books.active.selection
-    input_col_name_2 = active_cells.value
-    input_col_name_2_address = active_cells.address
+
 
     import sys
     from Excelutilities import importing_data_helpers
@@ -365,17 +392,26 @@ def generate_sku(allowed_data_types = [str]):
                 sys.exit()
 
     #sanity checks
-    sanity_check_col_entries(entry1=input_col_name_1, entry2=input_col_name_2, 
-                addresses_and_names=[(input_col_name_1_address, "col_name_1"),(input_col_name_2_address, "col_name_2")])
 
-    
-    def sku_helper(product_name):
-        if product_name == None:
-            return None
+
+    for asin,date in zip(asin_list,date_list):
+        date = datetime.datetime.strftime(date, '%d-%m-%Y')
+        if asin in asin_sku_dict:
+            sku_list.append([asin_sku_dict[asin]])
         else:
-            return "".join([char for char in product_name if char.isalpha()])[:15]    
+            sku_list.append([str(asin) + '-'+str(date)])
+
+    active_cells.value = [sku for sku in sku_list]
+
+
+    #def sku_helper(product_name):
+    #    if product_name == None:
+    #        return None
+    #    else:
+    #        return "".join([char for char in product_name if char.isalpha()])[:15]    
      
-    active_cells.value = [[sku_helper(product_name)] for product_name in input_col_name_1]
+    #active_cells.value = [[sku_helper(product_name)] for product_name in input_col_name_1]
+
 
 def generate_sku_process(use_process=False):
     """
@@ -394,15 +430,17 @@ def generate_sku_process(use_process=False):
 
 @debug_basic(True)
 def export_shipping_sheet():
+    max_num_asins_shipping = 500
+    max_num_asins_master = 5000
     select_name_and_click_ok_or_terminate(name="the shipping address data", keep_on_top=True,affirmative_response="OK")
     import xlwings as xw
     wb = xw.apps.active.books.active
     shipping_data_block = wb.selection.value
-    sg.popup("Currently, this only works with a max of 500 ASINs")
-    asin_qty_data = wb.sheets["Shipment form"].range("A2:B502").value
+    sg.popup(f"Currently, this only works with a max of {max_num_asins_shipping} ASINs")
+    asin_qty_data = wb.sheets["Shipment form"].range("A2:B"+str(2+max_num_asins_shipping)).value
     asin_qty_data = [row for row in asin_qty_data if row != [None, None]]
-    sg.popup("This temporary solution assumes you have max 5000 ASINs in your MASTER sheet")
-    master_data = wb.sheets["Master"].range("A2:"+master_data_last_letter+ "5000").value
+    sg.popup(f"This temporary solution assumes you have max {max_num_asins_master} ASINs in your MASTER sheet")
+    master_data = wb.sheets["Master"].range("A2:"+master_data_last_letter+ str(max_num_asins_master)).value
     asin_index = master_col_names_to_indices["ASIN"]
     sku_index = master_col_names_to_indices["SKU"]
 
@@ -411,8 +449,19 @@ def export_shipping_sheet():
 
     asins_to_skus = dict(zip(asins, skus))
 
+    #Now we get SKUs from inventory, and it takes priority over asins got from the master
+    max_num_asins_inventory = max_num_asins_master
+    from ArbMasterPy.inventory_data import get_attribute
+    inventory_asins_skus = get_attribute(attr='seller-sku')
+    for asin in inventory_asins_skus.keys():
+        if asin in asins_to_skus:
+            asins_to_skus[asin] = inventory_asins_skus[asin]
+
+    
+    #we keep track of all asins we couldn't find an sku for
     asins_without_sku = []
 
+    #we create an array, 2xN, with skus and qty data
     sku_qty_data = []
     for row in asin_qty_data:
         qty = row[1]
@@ -427,9 +476,41 @@ def export_shipping_sheet():
             asins_without_sku.append([asin, qty])
 
     sku_qty_data += asins_without_sku #i.e. all the asins with no SKUs go at the end
+    
+    #when skus or asins appear twice, we add the quantities and remove the second appearace
+    matching_index = 0 #This is collecting 0th column, i.e. the ASINs (could be selected)
+    value_index = 1 #This is collecting the quantities which are added (could be selected)
+    checking_list = []
+
+    #Find all the locations
+
+    for index, row in enumerate(sku_qty_data):
+        if sku_qty_data[index][matching_index] in checking_list:
+            pass
+        else:
+            checking_list.append(sku_qty_data[index][matching_index])
+
+
+    #Produce the new values
+    temp = 0
+    outputs = []
+    for asin in checking_list:
+        for row in sku_qty_data:
+            if row[matching_index] == asin:
+                temp += row[value_index]
+        outputs.append(temp)
+        temp = 0
+
+    #Replace the sku_qty_data with the new values
+
+    sku_qty_data = [list(a) for a in zip(checking_list, outputs)]
 
     return_value = [["PlanName", "NOT AUTOMATED YET"], ["ShipToCountry", "UK"]] + shipping_data_block + [["AddressDistrct",None],[None,None], ["MerchantSKU", "Quantity"]] + sku_qty_data
-    
+
+    print(f"SHIPPING DATA BLOCK IS: {shipping_data_block}")
+
+    print(f"SKU QTY DATA IS: {sku_qty_data}")
+
 
     import pkg_resources
 
@@ -465,5 +546,4 @@ def export_shipping_sheet_process(use_process=False):
 
 
 if __name__ == "__main__":
-   import platform
-   print(platform.system())
\ No newline at end of file
+   export_shipping_sheet()
\ No newline at end of file
